//	Copyright  1995 Apple Computer, Inc. All rights reserved.
//	Release Version:	$ 1.0 d11 $

//================================================================================
#ifndef WINDOIDPRT_H
#include "WindoidPrt.h"		// CWindoidPart
#endif

#ifndef _WINDOIDFRAME_
#include "WindoidFrm.h"		// CMainFrame, CPaletteFrame
#endif

#ifndef CONSTANT_H
#include "Constant.h"		// my menu command numbers
#endif

#ifndef WINDOIDDEF_H
#include "WindoidDef.h"		// kMainPresentation, kWindoidPresentation
#endif

// ----- Framework Layer -----
#ifndef FWPRESEN_H
#include "FWPresen.h"		// FW_CPresentation
#endif

#ifndef FWUTIL_H
#include "FWUtil.h"			// FW_Beep()
#endif

#ifndef FWABOUT_H
#include "FWAbout.h"		//::FW_About()
#endif

// ----- OS Layer -----
#ifndef FWFLOWIN_H
#include "FWFloWin.h"		// FW_CFloatingWindow
#endif

#ifndef   FWRESFIL_H
#include "FWResFil.h"		// FW_CResourceFile
#endif

#ifndef FWPICSHP_H
#include "FWPicShp.h"		// FW_PPicture
#endif
#ifndef FWMENU_H
#include "FWMenu.h"			// FW_CMenuBar, FW_CPullDownMenu
#endif

#ifndef FWCFMRES_H
#include "FWCFMRes.h"		// FW_CSharedLibraryResourceFile
#endif

#ifndef FWRESTYP_H
#include "FWResTyp.h"		// MULTISTRINGRES
#endif

#ifndef FWEVENT_H
#include "FWEvent.h"		// FW_CMenuEvent
#endif

#ifndef FWSUSINK_H
#include "FWSUSink.h"		// FW_CStorageUnitSink
#endif

// ----- OpenDoc Includes --------------
#ifndef SOM_Module_OpenDoc_StdProps_defined
#include <StdProps.xh>		// kODPropContents
#endif

#ifndef SOM_ODDispatcher_xh
#include "Disptch.xh"		// ODIdleFrequency
#endif

#ifndef SOM_ODSession_xh
#include <ODSessn.xh>		// ODSession
#endif

//==============================================================================
const ODValueType CWindoidPart::kPartKind = kWindoidKind;
const ODValueType CWindoidPart::kPartUserName = kWindoidEditorUserString;

//==============================================================================
#ifdef FW_BUILD_MAC
#pragma segment Windoid
#endif

//==============================================================================
CWindoidPart::CWindoidPart(ODPart* odPart)
  :	FW_CPart(odPart, kPartKind, kPartUserName, FW_gInstance, kPartIconID),
	fMainPresentation(NULL),
	fPalettePresentation(NULL),
	fPaletteWindow(NULL)
{
}

//--------------------------------------------------------------------------------
CWindoidPart::~CWindoidPart()
{
//	delete fPaletteWindow;
}

//--------------------------------------------------------------------------------
void 
CWindoidPart::Initialize(Environment* ev)	// Override
{
	FW_CPart::Initialize(ev);
	const FW_Boolean kDefault = TRUE;
	fMainPresentation = this->RegisterPresentation(ev, kMainPresentation, kDefault);
	fPalettePresentation = this->RegisterPresentation(ev, kPalettePresentation, !kDefault);
	this->MyInitMenus(ev);
//	this->MyMakePalette(ev);
}

//--------------------------------------------------------------------------------
void 
CWindoidPart::MyInitMenus(Environment* ev)
{
	FW_CSharedLibraryResourceFile 	resFile;
	FW_CPullDownMenu* menu = new FW_CPullDownMenu(ev, resFile, 
										kWindoidStringsResID, kPaletteMenuString);
	menu->AppendToggleItem(ev, resFile, kWindoidStringsResID, 
											kPaletteMenuString, 
											kHidePaletteItemStr, 
											cHideShowPalette, 'T');
	this->GetMenuBar(ev)->AdoptMenuLast(ev, menu);

}

//--------------------------------------------------------------------------------
void 
CWindoidPart::MyMakePalette(Environment* ev)
{
	if (fPaletteWindow == NULL)
	{
		FW_CSharedLibraryResourceFile	 resFile;	// palette picture here
		FW_PPicture picture(resFile, kPalettePictID);
		FW_CRect bounds;
		picture->GetPictBounds(bounds);
		FW_CPoint windowSize = bounds.Size();
		FW_CPoint windowPosition(FW_IntToFixed(100), FW_IntToFixed(100));
		const FW_Boolean kWantCloseBox = TRUE;
		const FW_CString32 kWindowTitle("");
		fPaletteWindow =  new FW_CFloatingWindow(ev, GetODPart(ev), 
				fPalettePresentation->GetPresentationType(ev), kWindowTitle, 
				windowSize, windowPosition, kWantCloseBox);
		fPaletteWindow->Show(ev);
	}
}

//--------------------------------------------------------------------------------
FW_Boolean 
CWindoidPart::DoAdjustMenus(Environment* ev, FW_CMenuBar* menuBar, 
									 FW_Boolean hasMenuFocus, FW_Boolean isRoot)
{
	if (hasMenuFocus) {
		menuBar->EnableAndToggleCommand(ev, cHideShowPalette, TRUE, 
								fPaletteWindow == NULL || !fPaletteWindow->IsShown(ev));
	}
	return FALSE;
}

//--------------------------------------------------------------------------------
FW_Boolean 
CWindoidPart::DoMenu(Environment* ev, const FW_CMenuEvent& theMenuEvent)	// Override
{
	FW_Boolean menuHandled = TRUE;
	ODCommandID commandID = theMenuEvent.GetCommandID(ev);
	
	switch (commandID)
	{
		case cHideShowPalette:
			fPaletteWindow->ShowHide(ev, ! fPaletteWindow->IsShown(ev));
			break;

		default:
			menuHandled = FALSE;
	}
	
	return menuHandled;
}

//--------------------------------------------------------------------------------
FW_CFrame* 
CWindoidPart::NewFrame(Environment* ev, ODFrame* odFrame,
						FW_CPresentation* presentation, FW_Boolean fromStorage)	// Override
{
	FW_UNUSED(fromStorage);
	if (presentation == fPalettePresentation) {
		return (new CPaletteFrame(ev, odFrame, presentation, this));
	}
	return new CMainFrame(ev, odFrame, presentation, this);
}

